@@ -29,6 +29,8 @@ import javax.xml.parsers.SAXParserFactory;
 
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
+import org.xml.sax.SAXNotRecognizedException;
+import org.xml.sax.SAXNotSupportedException;
 import org.xml.sax.XMLReader;
 import org.xml.sax.helpers.DefaultHandler;
 
@@ -48,6 +50,15 @@ import org.apache.vinci.transport.util.TransportableConverter;
  */
 public class XMLToVinci {
 
+  private static final SAXParserFactory spf = SAXParserFactory.newInstance();
+  static {
+    try {
+      spf.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
+    } catch (SAXNotRecognizedException | SAXNotSupportedException
+        | ParserConfigurationException e) {
+      System.err.println("Warning: SAXParserFactory didn't recognized the feature http://apache.org/xml/features/disallow-doctype-decl");
+    }
+  }
   /**
    * Utility class not intended to be instantiated.
    */
@@ -243,7 +254,9 @@ public class XMLToVinci {
   public static VinciFrame xmlToVinciFrame(Reader r) throws ServiceException {
     XMLReader xr;
     try {
-      xr = SAXParserFactory.newInstance().newSAXParser().getXMLReader();
+      synchronized(spf) {
+        xr = spf.newSAXParser().getXMLReader();
+      }
     } catch (SAXException e) {
       throw new ServiceException("Error creating SAX Parser: " + e);
     } catch (ParserConfigurationException e) {
@@ -251,7 +264,13 @@ public class XMLToVinci {
     }
     // prevent undeclared namespace warnings.
     try {
-      xr.setFeature("http://xml.org/sax/features/namespaces", false);
+      try {
+        xr.setFeature("http://xml.org/sax/features/namespaces", false);
+      } catch (SAXNotRecognizedException e) {
+        System.err.println("Warning: XMLReader didn't recognize the feature http://xml.org/sax/features/namespaces");
+      } catch (SAXNotSupportedException e) {
+        System.err.println("Warning: XMLReader doesn't support the feature http://xml.org/sax/features/namespaces");
+      }
       VinciFrameHandler handler = new VinciFrameHandler();
       xr.setContentHandler(handler);
       xr.setErrorHandler(handler);
@@ -284,7 +303,9 @@ public class XMLToVinci {
   public static AFrame xmlToAFrame(Reader r) throws ServiceException {
     XMLReader xr;
     try {
-      xr = SAXParserFactory.newInstance().newSAXParser().getXMLReader();
+      synchronized (spf) {
+        xr = spf.newSAXParser().getXMLReader();
+      }
     } catch (SAXException e) {
       throw new ServiceException("Error creating SAX Parser: " + e);
     } catch (ParserConfigurationException e) {
