@@ -55,12 +55,12 @@ public class FlowContainer {
     mCAS = (CASImpl)aCAS;
   }
 
-  public FlowContainer newCasProduced(CAS newCAS, String producedBy)
+  public FlowContainer newCasProduced(final CAS newCAS, String producedBy)
           throws AnalysisEngineProcessException {
     mTimer.startIt();
     CAS view = null;
     try {
-      view = Util.getStartingView(
+      view = Util.getStartingView(   
           newCAS, 
           mSofaAware, 
           mFlowControllerContainer.getUimaContextAdmin().getComponentInfo());
@@ -81,9 +81,9 @@ public class FlowContainer {
     } catch (CASException e) {
       throw new AnalysisEngineProcessException(e);
     } finally {
+      newCAS.setCurrentComponentInfo(null);
       if (null != view) {
         ((CASImpl)view).restoreClassLoaderUnlockCas();
-        view.setCurrentComponentInfo(null);
       }
       mTimer.stopIt();
       getMBean().reportAnalysisTime(mTimer.getDuration());
@@ -109,6 +109,8 @@ public class FlowContainer {
       mFlow.aborted();
     } finally {
       mCAS.restoreClassLoaderUnlockCas();
+      // https://issues.apache.org/jira/browse/UIMA-6057
+      mCAS.restoreClassLoaderUnlockCas();  // this one unlocks the aborted CAS itself
     }
   }
   
@@ -118,6 +120,8 @@ public class FlowContainer {
       return mFlow.continueOnFailure(failedAeKey, failure);
     } finally {
       mCAS.restoreClassLoaderUnlockCas();
+      // https://issues.apache.org/jira/browse/UIMA-6057
+      mCAS.restoreClassLoaderUnlockCas();  // this one unlocks the failed CAS itself
     }
   }
 
