@@ -76,7 +76,7 @@ import org.xml.sax.SAXException;
 /**
  * Reference implementation of {@link AnalysisEngineDescription}. Note that this class contains two
  * attributes of class Map, which are not supported by the default XML input/output routines.
- * Therefore we override the {@link MetaDataObject_impl#writePropertyAsElement(PropertyXmlInfo, String, ContentHandler)} and
+ * Therefore we override the {@link MetaDataObject_impl#writePropertyAsElement(PropertyXmlInfo, String)} and
  * {@link MetaDataObject_impl#readPropertyValueFromXMLElement(PropertyXmlInfo, Element, XMLParser, XMLParser.ParsingOptions)} methods.
  * 
  * 
@@ -445,7 +445,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
       componentSpecifier = getFlowControllerDeclaration().getSpecifier();
     } else {
       try {
-        componentSpecifier = (ResourceSpecifier) getDelegateAnalysisEngineSpecifiers().get(key);
+        componentSpecifier = getDelegateAnalysisEngineSpecifiers().get(key);
       } catch (InvalidXMLException e) {
         throw new ResourceInitializationException(e);
       }
@@ -455,6 +455,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
 
   /**
    * Validate SofA mappings and inputs/outputs for an aggregate AE.
+   * @throws ResourceInitializationException -
    */
   protected void validateSofaMappings() throws ResourceInitializationException {
     if (this.isPrimitive())
@@ -490,7 +491,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
                 + sofaMappings[s].getComponentSofaName();
         String aggSofaName = sofaMappings[s].getAggregateSofaName();
         // check for double-mapping
-        String existingMapping = (String) sofamap.get(compoundKey);
+        String existingMapping = sofamap.get(compoundKey);
         if (existingMapping != null && !existingMapping.equals(aggSofaName)) {
           throw new ResourceInitializationException(
                   ResourceInitializationException.SOFA_MAPPING_CONFLICT, new Object[] {
@@ -539,7 +540,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
           // all component output sofas must be mapped to aggregate output sofas
           String[] outputSofas = caps[i].getOutputSofas();
           for (int j = 0; j < outputSofas.length; j++) {
-            String aggSofa = (String) sofamap.get(componentKey + "@/@" + outputSofas[j]);
+            String aggSofa = sofamap.get(componentKey + "@/@" + outputSofas[j]);
             if (aggSofa == null) // no declared mapping, name remains unchanged
             {
               aggSofa = outputSofas[j];
@@ -555,7 +556,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
           // all component input sofas must be mapped to aggregate input OR output sofas
           String[] inputSofas = caps[i].getInputSofas();
           for (int j = 0; j < inputSofas.length; j++) {
-            String aggSofa = (String) sofamap.get(componentKey + "@/@" + inputSofas[j]);
+            String aggSofa = sofamap.get(componentKey + "@/@" + inputSofas[j]);
             if (aggSofa == null) // no declared mapping, name remains unchanged
             {
               aggSofa = inputSofas[j];
@@ -569,7 +570,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
           }
 
           // also check default text sofa
-          String aggDefSofa = (String) sofamap.get(componentKey + "@/@" + CAS.NAME_DEFAULT_SOFA);
+          String aggDefSofa = sofamap.get(componentKey + "@/@" + CAS.NAME_DEFAULT_SOFA);
           if (aggDefSofa != null) {
             if (capabilitiesContainSofa(aggDefSofa, true)) {
               correctlyMappedAggregateOutputs.add(aggDefSofa);
@@ -770,8 +771,10 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
    * delegateAnalysisEngineSpecifiersWithImports map and populates the
    * delegateAnalysisEngineSpecifiers map. 
    * 
+   * @param aResourceManager -
    * @param aRecursive If true, this method will call {@link #resolveImports(Collection, ResourceManager)} 
    *   on each delegate. If a cirular import is found, an exception will be thrown.
+   * @throws InvalidXMLException -
    */
   protected void resolveDelegateAnalysisEngineImports(ResourceManager aResourceManager, boolean aRecursive) 
           throws InvalidXMLException {
@@ -789,8 +792,10 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
    * delegateAnalysisEngineSpecifiers map. 
    * 
    * @param aEnclosingAggregateAeUrls URLs of enclosing aggregate AEs.  Used to detect circular imports.
+   * @param aResourceManager - 
    * @param aRecursive If true, this method will call {@link #resolveImports(Collection, ResourceManager)} 
    *   on each delegate. If a circular import is found, an exception will be thrown.
+   * @throws InvalidXMLException -
    */
   protected synchronized void resolveDelegateAnalysisEngineImports(Collection<String> aEnclosingAggregateAeUrls,
           ResourceManager aResourceManager, boolean aRecursive) throws InvalidXMLException {
@@ -880,11 +885,14 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
    * attribute has a value of type <code>Map</code>, which is not handled by the default XML
    * export logic.
    * 
-   * @see org.apache.uima.resource.metadata.impl.MetaDataObject_impl#writePropertyAsElement(PropertyXmlInfo,String,ContentHandler)
+   * @see org.apache.uima.resource.metadata.impl.MetaDataObject_impl#writePropertyAsElement(PropertyXmlInfo, String)
+   * @param aPropInfo -
+   * @param aNamespace - 
+   * @throws SAXException -
    */
   @Override
-  protected void writePropertyAsElement(PropertyXmlInfo aPropInfo, String aNamespace,
-          ContentHandler aContentHandler) throws SAXException {
+  protected void writePropertyAsElement(PropertyXmlInfo aPropInfo, String aNamespace) throws SAXException {
+
     if (PROP_DELEGATE_ANALYSIS_ENGINE_SPECIFIERS_WITH_IMPORTS.equals(aPropInfo.propertyName)) {
       // special logic here -- if imports have been resolved, then we want
       // to write
@@ -898,10 +906,10 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
         propName = PROP_DELEGATE_ANALYSIS_ENGINE_SPECIFIERS_WITH_IMPORTS;
       }
       writeMapPropertyToXml(propName, ELEM_DELEGATE_ANALYSIS_ENGINE_SPECIFIERS, "key",
-              "delegateAnalysisEngine", aPropInfo.omitIfNull, aNamespace, aContentHandler);
+              "delegateAnalysisEngine", aPropInfo.omitIfNull, aNamespace);
     } else {
       // for all other attributes, use the default superclass behavior
-      super.writePropertyAsElement(aPropInfo, aNamespace, aContentHandler);
+      super.writePropertyAsElement(aPropInfo, aNamespace);
     }
   }
 
@@ -927,7 +935,12 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
 
   /**
    * Overridden to set default operational properties if they are not specified in descriptor.
+   * @param aElement -
+   * @param aParser - 
+   * @param aOptions -
+   * @throws InvalidXMLException - 
    */
+  @Override
   public void buildFromXMLElement(Element aElement, XMLParser aParser, ParsingOptions aOptions)
           throws InvalidXMLException {
     super.buildFromXMLElement(aElement, aParser, aOptions);
@@ -946,6 +959,7 @@ public class AnalysisEngineDescription_impl extends ResourceCreationSpecifier_im
 
   /**
    * Static method to get XmlizationInfo, used by subclasses to set up their own XmlizationInfo.
+   * @return XmlizationInfo, used by subclasses to set up their own XmlizationInfo
    */
   protected static XmlizationInfo getXmlizationInfoForClass() {
     return XMLIZATION_INFO;
