@@ -31,6 +31,7 @@ import org.apache.uima.UIMAFramework;
 import org.apache.uima.UimaContext;
 import org.apache.uima.UimaContextAdmin;
 import org.apache.uima.analysis_engine.AnalysisEngine;
+import org.apache.uima.analysis_engine.AnalysisEngineDescription;
 import org.apache.uima.analysis_engine.AnalysisEngineProcessException;
 import org.apache.uima.analysis_engine.CasIterator;
 import org.apache.uima.analysis_engine.ResultSpecification;
@@ -39,6 +40,7 @@ import org.apache.uima.cas.CAS;
 import org.apache.uima.cas.TypeSystem;
 import org.apache.uima.impl.ChildUimaContext_impl;
 import org.apache.uima.pear.tools.PackageBrowser;
+import org.apache.uima.resource.Parameter;
 import org.apache.uima.resource.PearSpecifier;
 import org.apache.uima.resource.Resource;
 import org.apache.uima.resource.ResourceConfigurationException;
@@ -47,6 +49,7 @@ import org.apache.uima.resource.ResourceManager;
 import org.apache.uima.resource.ResourceProcessException;
 import org.apache.uima.resource.ResourceSpecifier;
 import org.apache.uima.resource.impl.ResourceManager_impl;
+import org.apache.uima.resource.metadata.ConfigurationParameterSettings;
 import org.apache.uima.resource.metadata.ProcessingResourceMetaData;
 import org.apache.uima.resource.metadata.ResourceMetaData;
 import org.apache.uima.util.InvalidXMLException;
@@ -82,11 +85,11 @@ public class PearAnalysisEngineWrapper extends AnalysisEngineImplBase {
    // incoming Resource Manager, and a second map.
    // The second map (allows for multiple Pears in a pipeline)
    // maps (for the given incoming Resource Manager), using a key
-   // consisting of the "class path" and "data path", the 
+   // consisting of the the PEARs "class path" and "data path", the 
    // Resource Manager for that combination.
 
    // note: all accesses to this are synchronized
-   static private Map<ResourceManager, Map<StringPair, ResourceManager>> cachedResourceManagers =
+   static final private Map<ResourceManager, Map<StringPair, ResourceManager>> cachedResourceManagers =
      new WeakHashMap<ResourceManager, Map<StringPair, ResourceManager>>(4);
 
    private AnalysisEngine ae = null;
@@ -258,6 +261,20 @@ public class PearAnalysisEngineWrapper extends AnalysisEngineImplBase {
 
       // Parse the resource specifier
       ResourceSpecifier specifier = UIMAFramework.getXMLParser().parseResourceSpecifier(in);
+      
+      AnalysisEngineDescription analysisEngineDescription = (AnalysisEngineDescription) specifier;
+      AnalysisEngineMetaData analysisEngineMetaData = analysisEngineDescription
+              .getAnalysisEngineMetaData();
+      ConfigurationParameterSettings configurationParameterSettings = analysisEngineMetaData
+              .getConfigurationParameterSettings();
+      Parameter[] parameters = pearSpec.getParameters();
+
+      if (parameters != null) {
+        for (Parameter parameter : parameters) {
+          configurationParameterSettings.setParameterValue(parameter.getName(),
+                  parameter.getValue());
+        }
+      }
 
       UimaContextAdmin uimaContext = (aAdditionalParams == null) ? null
           : (UimaContextAdmin) aAdditionalParams.get(Resource.PARAM_UIMA_CONTEXT);
@@ -593,7 +610,7 @@ public class PearAnalysisEngineWrapper extends AnalysisEngineImplBase {
     * inner class StringPair
     * 
     */
-   static private class StringPair {
+   static public class StringPair {
 
       private String classPath;
 
@@ -637,4 +654,11 @@ public class PearAnalysisEngineWrapper extends AnalysisEngineImplBase {
          return true;
       }
    }
+
+  /**
+   * @return the cachedResourceManagers
+   */
+  static public Map<ResourceManager, Map<StringPair, ResourceManager>> getCachedResourceManagers() {
+    return cachedResourceManagers;
+  }
 }
