@@ -51,6 +51,7 @@ import org.apache.uima.cas.impl.CASImpl;
 import org.apache.uima.jcas.JCas;
 import org.apache.uima.resource.CasManager;
 import org.apache.uima.resource.ResourceAccessException;
+import org.apache.uima.resource.ResourceConfigurationException;
 import org.apache.uima.resource.ResourceInitializationException;
 import org.apache.uima.resource.metadata.ConfigurationGroup;
 import org.apache.uima.resource.metadata.ConfigurationParameter;
@@ -219,7 +220,24 @@ public abstract class UimaContext_ImplBase implements UimaContextAdmin {
    * @see org.apache.uima.UimaContextAdmin#createChild(java.lang.String)
    */
   public UimaContextAdmin createChild(String aContextName, Map<String, String> aSofaMappings) {
-    // The aSofaMappings parameter, if present, defines the mapping between the child
+
+    // create child context with the absolute mappings
+    ChildUimaContext_impl child = new ChildUimaContext_impl(this, aContextName, combineSofaMappings(aSofaMappings));
+
+    // build a tree of MBeans that parallels the tree of UimaContexts
+    mMBean.addComponent(aContextName, child.mMBean);
+
+    return child;
+  }
+
+  /**
+   * Create the child sofa map by combining existing mapping from the current context with
+   * any mappings specific for this child, passed in as aSofaMappings
+   * @param aSofaMappings -
+   * @return the combined absolute sofamappings
+   */
+  public Map<String, String> combineSofaMappings(Map<String, String> aSofaMappings) {
+ // The aSofaMappings parameter, if present, defines the mapping between the child
     // context's sofa names and this context's sofa names. This context's sofa names
     // may again be remapped (according to the mSofaMappings field). We need to
     // produce the absolute mapping and pass that into the child context's constructor.
@@ -241,16 +259,8 @@ public abstract class UimaContext_ImplBase implements UimaContextAdmin {
         childSofaMap.put(childSofaName, absoluteSofaName);
       }
     }
-
-    // create child context with the absolute mappings
-    ChildUimaContext_impl child = new ChildUimaContext_impl(this, aContextName, childSofaMap);
-
-    // build a tree of MBeans that parallels the tree of UimaContexts
-    mMBean.addComponent(aContextName, child.mMBean);
-
-    return child;
+    return childSofaMap;
   }
-
   /**
    * @see org.apache.uima.analysis_engine.annotator.AnnotatorContext#getConfigParameterValue(java.lang.String)
    */
@@ -267,6 +277,28 @@ public abstract class UimaContext_ImplBase implements UimaContextAdmin {
             aGroupName);
   }
 
+  @Override
+  public String getSharedSettingValue(String name) throws ResourceConfigurationException {
+    Settings settings = getRootContext().getExternalOverrides();
+    return (settings == null) ? null : settings.getSetting(name);
+  }
+  
+  @Override
+  public String[] getSharedSettingArray(String name) throws ResourceConfigurationException {
+    Settings settings = getRootContext().getExternalOverrides();
+    return (settings == null) ? null : settings.getSettingArray(name);
+  }
+  
+  @Override
+  public String[] getSharedSettingNames() {
+    Settings settings = getRootContext().getExternalOverrides();
+    if (settings == null) {
+      return null;
+    }
+    Set<String> names = settings.getKeys();
+    return names.toArray(new String[names.size()]);
+  }
+  
   /**
    * Locates Resource URL's using the ResourceManager.
    * 
@@ -565,7 +597,7 @@ public abstract class UimaContext_ImplBase implements UimaContextAdmin {
   public void setExternalOverrides(Settings externalOverrides) {
     getRootContext().setExternalOverrides(externalOverrides);
   }
-  
+
   /**
    * Changes here should also be made in UimaContext_ImplBase.mapToSofaID (non-Javadoc)
    * 
