@@ -526,7 +526,7 @@ class IntRBTNode {
       if (addressStack.empty()) {
         node = null;
       } else {
-        node = (IntRBTNode) nodeStack.pop();
+        node = nodeStack.pop();
         address = addressStack.pop();
         v.set(address, v.size() + offset);
       }
@@ -565,7 +565,7 @@ class IntRBTNode {
       System.out.print(' ');
     }
     System.out.print(this.key);
-    System.out.print(":");
+    System.out.print(':');
     if (this.color == RED) {
       System.out.println("red");
     } else {
