@@ -19,7 +19,7 @@
 
 package org.apache.uima.internal.util;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 import junit.framework.TestCase;
 
 import org.apache.uima.UIMAFramework;
