@@ -25,30 +25,38 @@ import junit.framework.TestCase;
 
 public class OptimizeStringsTest extends TestCase {
 
-  private static Field STRING_OFFSET;
-  static {
-    try {
-      STRING_OFFSET = String.class.getDeclaredField("offset");
-      STRING_OFFSET.setAccessible(true);
-    } catch (SecurityException e) {
-      throw new RuntimeException(e);
-    } catch (NoSuchFieldException e) {
-      System.err.println("OptimizeStringsTest could not find the String offset field, skipping that part of the test.");
-      STRING_OFFSET = null;
-    }
-  }
+  // modern Javas do this in various ways, can't depend on internal impl
+//  private static Field STRING_OFFSET;
+//  static {
+//    try {
+//   // Found that IBM Java 8 version 8.0.4.2 returns a value for the field "offset", but it's 0
+//      // and there doesn't seem to be an offset field in that class.
+//      if (System.getProperty("java.version").startsWith("1.8")) {
+//        STRING_OFFSET = null;
+//      } else {
+//        STRING_OFFSET =  String.class.getDeclaredField("offset");
+//        STRING_OFFSET.setAccessible(true);
+//      }
+//    } catch (SecurityException e) {
+//      throw new RuntimeException(e);
+//    } catch (NoSuchFieldException e) {
+//      System.err.println("OptimizeStringsTest could not find the String offset field, skipping that part of the test.");
+//      STRING_OFFSET = null;
+//    }
+//  }
     
   public static int getStringOffset(String s) {
-    try {
-      if (STRING_OFFSET != null) {
-        return STRING_OFFSET.getInt(s);
-      }
-      return -1;
-    } catch (IllegalArgumentException e) {
-      throw new RuntimeException(e);
-    } catch (IllegalAccessException e) {
-      throw new RuntimeException(e);
-    }
+    return -1;  // disabled
+//    try {
+//      if (STRING_OFFSET != null) {
+//        return STRING_OFFSET.getInt(s);
+//      }
+//      return -1;
+//    } catch (IllegalArgumentException e) {
+//      throw new RuntimeException(e);
+//    } catch (IllegalAccessException e) {
+//      throw new RuntimeException(e);
+//    }
   }
    
   public void testOpStr() {
