@@ -72,6 +72,7 @@ import org.apache.uima.collection.metadata.CpeDescriptorException;
 import org.apache.uima.collection.metadata.CpeResourceManagerConfiguration;
 import org.apache.uima.collection.metadata.CpeSofaMapping;
 import org.apache.uima.collection.metadata.CpeSofaMappings;
+import org.apache.uima.internal.util.Class_TCCL;
 import org.apache.uima.resource.ConfigurableResource_ImplBase;
 import org.apache.uima.resource.Resource;
 import org.apache.uima.resource.ResourceConfigurationException;
@@ -127,6 +128,7 @@ public class CPEFactory {
 
   /**
    * Create a new CPEFactory on which we will later call parse(String) to parse a CPE descriptor.
+   * @param aResourceManager -
    */
   public CPEFactory(ResourceManager aResourceManager) {
     if (aResourceManager == null) {
@@ -139,10 +141,11 @@ public class CPEFactory {
   /**
    * Create a new CPEFactory for a CpeDescription that's already been parsed.
    * 
-   * @param aDescriptor
-   * @param aResourceManager
+   * @param aDescriptor -
+   * @param aResourceManager 
    *          the resource manager that all components of this CPE will share If null, a new
    *          ResourceManager will be created.
+   * @throws ResourceInitializationException -
    */
   public CPEFactory(CpeDescription aDescriptor, ResourceManager aResourceManager)
           throws ResourceInitializationException {
@@ -279,7 +282,7 @@ public class CPEFactory {
    * 
    * @return CollectionReader instance
    * 
-   * @throws ResourceConfigurationException
+   * @throws ResourceConfigurationException -
    */
   public BaseCollectionReader getCollectionReader() throws ResourceConfigurationException {
     checkForErrors();
@@ -638,16 +641,7 @@ public class CPEFactory {
       } else {
         // String className = ((CasConsumerDescription) resourceSpecifier).getImplementationName();
         // load class using UIMA Extension ClassLoader if there is one
-        ClassLoader cl = null;
-        ResourceManager rm = getResourceManager();
-        if (rm != null) {
-          cl = rm.getExtensionClassLoader();
-        }
-        if (cl == null) {
-          cl = this.getClass().getClassLoader();
-        }
-        // Class currentClass = Class.forName(className, true, cl);
-        Class currentClass = Class.forName(implementationClass, true, cl);
+        Class currentClass = Class_TCCL.forName(implementationClass, getResourceManager());
 
         // check to see if this is a subclass of aResourceClass
         if (aResourceClass.isAssignableFrom(currentClass)) {
@@ -735,15 +729,7 @@ public class CPEFactory {
     try {
       className = ((CasInitializerDescription) aSpecifier).getImplementationName();
       // load class using UIMA Extension ClassLoader if there is one
-      ClassLoader cl = null;
-      ResourceManager rm = getResourceManager();
-      if (rm != null) {
-        cl = rm.getExtensionClassLoader();
-      }
-      if (cl == null) {
-        cl = this.getClass().getClassLoader();
-      }
-      Class currentClass = Class.forName(className, true, cl);
+      Class<?> currentClass = Class_TCCL.forName(className, getResourceManager());
       Object initializer = currentClass.newInstance();
       // check to see if this is a subclass of aResourceClass
       if (initializer instanceof CasInitializer) {
@@ -1148,7 +1134,7 @@ public class CPEFactory {
    * </ul>
    * 
    * @return Global CPE Configuration
-   * @throws InstantiationException
+   * @throws InstantiationException -
    */
   public CpeConfiguration getCPEConfig() throws InstantiationException {
     try {
@@ -1329,6 +1315,7 @@ public class CPEFactory {
    * 
    * @param aCasProcessor -
    *          CasProcessor to add
+   * @throws ResourceConfigurationException -
    */
   public void addCasProcessor(CasProcessor aCasProcessor) throws ResourceConfigurationException {
     if (!initialized) {
@@ -1434,7 +1421,7 @@ public class CPEFactory {
 
   /**
    * 
-   * @param aList
+   * @param aList -
    * @return the cpe descriptor constructed from the list
    * @throws ResourceConfigurationException -
    */
