@@ -165,6 +165,8 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
    *          CasProcessor configuration as defined in cpe descriptor
    * @param aCasProcessorPool -
    *          pool of CasProcessor instances
+   * @param aMetaData -
+   * @throws ResourceConfigurationException -
    */
   public ProcessingContainer_Impl(CasProcessorConfiguration aCasProcessorConfig,
           ProcessingResourceMetaData aMetaData, ServiceProxyPool aCasProcessorPool)
@@ -183,7 +185,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
 
   /**
    * Returns component's input/output capabilities
-   * 
+   * @return component's input/output capabilities
    */
   public ProcessingResourceMetaData getMetadata() {
     return metadata;
@@ -1000,7 +1002,7 @@ public Object getLastCas() {
         }
 
         if ((filterExpression.getOperand() == null
-                && filterExpression.getOperand().getOperand() == null && !exists)
+                || filterExpression.getOperand().getOperand() == null || !exists)
                 || // this means that the feature must exist in CAS
                 ("!".equals(filterExpression.getOperand().getOperand()) && exists)) // this
         // means
