@@ -24,16 +24,23 @@ import java.util.Comparator;
 
 import org.apache.uima.cas.text.AnnotationFS;
 
+
 /**
  * Checks two annotations for equality.
  */
 public class AnnotationComparator implements Comparator<AnnotationFS>, Serializable  {
   
+  /** The Constant serialVersionUID. */
   private static final long serialVersionUID = 1L;
 
   /**
    * Compares the given annotations a and b. This implementations only compares the begin index.
+   *
+   * @param a the a
+   * @param b the b
+   * @return the int
    */
+  @Override
   public int compare(AnnotationFS a, AnnotationFS b) {
     return a.getBegin() - b.getBegin();
   }
