@@ -76,9 +76,9 @@ import org.apache.uima.util.XMLizable;
 
 public class Jg {
 
+  private final static boolean IS_TRACE_LIMITED = false;
   /**
-   * Interface implemeted by JCAS code generation's templates
-   *
+   * Interface implemented by JCAS code generation's templates.
    */
   public interface IJCasTypeTemplate {
     public String generate(Object argument);
@@ -285,6 +285,9 @@ public class Jg {
 
   /**
    * Returns the string from the plugin's resource bundle, or 'key' if not found.
+   *
+   * @param key the key
+   * @return the resource string
    */
   public String getResourceString(String key) {
     ResourceBundle bundle = getResourceBundle();
@@ -300,7 +303,9 @@ public class Jg {
   }
 
   /**
-   * Returns the plugin's resource bundle,
+   * Returns the plugin's resource bundle,.
+   *
+   * @return the resource bundle
    */
   public ResourceBundle getResourceBundle() {
     return resourceBundle;
@@ -429,7 +434,9 @@ public class Jg {
    *   -jcasgenoutput  xxxx
    *   -jcasgenclasspath xxxx
    *   
-   * @param arguments
+   *
+   * @param arguments the arguments
+   * @return the int
    */
   public int main1(String[] arguments) {
     boolean hadError = false;
@@ -709,15 +716,22 @@ public class Jg {
    */
 
   /**
-   * return true if td is not defined in this project, of
+   * return true if td is not defined in this project, or
    *   it is defined, but is also in merged and any of the other
-   *   merged urls are not defined in this project
+   *   merged urls are not defined in this project.
+   *
+   * @param td the td
+   * @param projectDirPath the project dir path
+   * @return true, if is out of scope
    */
   private boolean isOutOfScope(TypeDescription td, String projectDirPath) {
     URI typeDefinitionUri;
     try {
       typeDefinitionUri = new URI (td.getSourceUrlString());
     } catch (URISyntaxException e) {
+      if (IS_TRACE_LIMITED) {
+        error.newError(IError.INFO, "debug isOutOfScope: got URISyntaxException, td.getSourceUrlstring: " + ((td.getSourceUrlString() == null) ? "null" : td.getSourceUrlString()), e);
+      }
       return true; // may be overkill - but if td's source can't be parsed ... likely out of project
     }
     String tdPath = typeDefinitionUri.getPath();
@@ -725,6 +739,9 @@ public class Jg {
     // Issue UIMA-4080 - If a type system resides in a JAR, then the path is null and it is
     // certainly out of scope.
     if (tdPath == null) {
+      if (IS_TRACE_LIMITED) {
+        error.newError(IError.INFO, "debug isOutOfScope: typeDefinitionUri had null path. " + typeDefinitionUri.toString(), null);
+      }
         return true;
     }
 
@@ -735,7 +752,7 @@ public class Jg {
     // as well as clients that use file-system notation (e.g. jcasgen-maven-plugin or a simple
     // invocation from the command line.
     String resolvedProjectPath;
-    if (!projectDirPath.startsWith("/")) {
+    if (!projectDirPath.startsWith("/")) { 
         resolvedProjectPath = new File(projectDirPath).getAbsoluteFile().toURI().getPath();
     }
     else {
@@ -754,6 +771,10 @@ public class Jg {
 
     boolean r = !tdPath.startsWith(resolvedProjectPath);
     if (r) {
+      if (IS_TRACE_LIMITED) {
+        error.newError(IError.INFO, "debug isOutOfScope: tdPath doesn't start with resolved ProjectPath, tdPath: "
+             + tdPath + ", resolvedProjectPath: " + resolvedProjectPath, null);
+      }
       return true;
     }
     Set<String> mergedPaths = mergedTypesAddingFeatures.get(td.getName());
@@ -767,6 +788,9 @@ public class Jg {
         }
         String tempPath = tempURI.getPath();
         if (!tempPath.startsWith(resolvedProjectPath)) {
+          if (IS_TRACE_LIMITED) {
+            error.newError(IError.INFO, "debug isOutOfScope due to mergedType adding feature", null);
+          }
           return true; 
         }
       }
@@ -781,9 +805,6 @@ public class Jg {
    * @param jcasTypeInstance          Template instance used to generate class
    * @param jcas_TypeInstance         Template instance used to generate class
    * @throws IOException -
-   * @throws InstantiationException -
-   * @throws IllegalAccessException -
-   * @return void
    */
   private void generateClassesFromTemplate(TypeDescription td, String outputDirectory,
           IJCasTypeTemplate jcasTypeInstance, IJCasTypeTemplate jcas_TypeInstance)
